searchNodes=[{"ref":"UTCDateTime.html","title":"UTCDateTime","type":"module","doc":"A datetime implementation constraint to UTC."},{"ref":"UTCDateTime.html#__using__/1","title":"UTCDateTime.__using__/1","type":"macro","doc":"A datetime implementation constraint to UTC."},{"ref":"UTCDateTime.html#from_datetime/1","title":"UTCDateTime.from_datetime/1","type":"function","doc":"Converts the given datetime into a UTCDateTime. Any datetime with a none UTC time zone will be converted to UTC. Examples iex&gt; dt = %DateTime{year: 2000, month: 2, day: 29, zone_abbr: &quot;UTC&quot;, ...&gt; hour: 23, minute: 0, second: 7, microsecond: {0, 1}, ...&gt; utc_offset: 0, std_offset: 0, time_zone: &quot;Etc/UTC&quot;} iex&gt; UTCDateTime.from_datetime(dt) ~Z[2000-02-29 23:00:07.0] iex&gt; dt = %DateTime{year: 2000, month: 2, day: 29, zone_abbr: &quot;CET&quot;, ...&gt; hour: 23, minute: 0, second: 7, microsecond: {0, 1}, ...&gt; utc_offset: 3600, std_offset: 0, time_zone: &quot;Europe/Warsaw&quot;} iex&gt; UTCDateTime.from_datetime(dt) ~Z[2000-02-29 22:00:07.0]"},{"ref":"UTCDateTime.html#from_naive/1","title":"UTCDateTime.from_naive/1","type":"function","doc":"Converts the given NaiveDateTime to UTCDateTime. It expects the given naive_datetime to be in the &quot;Etc/UTC&quot; time zone. Examples iex&gt; UTCDateTime.from_naive(~N[2016-05-24 13:26:08.003]) ~Z[2016-05-24 13:26:08.003]"},{"ref":"UTCDateTime.html#sigil_Z/2","title":"UTCDateTime.sigil_Z/2","type":"macro","doc":"Handles the sigil ~Z to create a UTCDateTime. By default, this sigil requires UTC date times to be written in the ISO8601 format: ~Z[yyyy-mm-dd hh:mm:ssZ] ~Z[yyyy-mm-dd hh:mm:ss.ssssssZ] ~Z[yyyy-mm-ddThh:mm:ss.ssssss+00:00] such as: ~Z[2015-01-13 13:00:07Z] ~Z[2015-01-13T13:00:07.123+00:00] The given utc_datetime_string must include &quot;Z&quot; or &quot;00:00&quot; offset which marks it as UTC, otherwise an error is raised. The lower case ~z variant does not exist as interpolation and escape characters are not useful for date time sigils. More information on date times can be found in the UTCDateTime module. Examples iex&gt; ~Z[2015-01-13 13:00:07Z] ~Z[2015-01-13 13:00:07Z] iex&gt; ~Z[2015-01-13T13:00:07.001+00:00] ~Z[2015-01-13 13:00:07.001Z]"},{"ref":"UTCDateTime.html#to_datetime/2","title":"UTCDateTime.to_datetime/2","type":"function","doc":"Converts the given UTCDateTime to NaiveDateTime. The given utc_datetime does not contain a calendar, so Calendar.ISO is set by default. It is possible to manually pass a different calendar. Examples iex&gt; UTCDateTime.to_datetime(~Z[2016-05-24 13:26:08.003]) ~U[2016-05-24 13:26:08.003Z]"},{"ref":"UTCDateTime.html#to_naive/2","title":"UTCDateTime.to_naive/2","type":"function","doc":"Converts the given UTCDateTime into a NaiveDateTime. The given utc_datetime does not contain a calendar, so Calendar.ISO is set by default. It is possible to manually pass a different calendar. Examples iex&gt; dt = %UTCDateTime{year: 2016, month: 5, day: 24, ...&gt; hour: 13, minute: 26, second: 8, ...&gt; microsecond: {3000, 3}} iex&gt; UTCDateTime.to_naive(dt) ~N[2016-05-24 13:26:08.003]"},{"ref":"UTCDateTime.html#to_rfc3339/1","title":"UTCDateTime.to_rfc3339/1","type":"function","doc":"Placeholder Convert utc_datetime to RFC3339 string format. Examples iex&gt; UTCDateTime.to_rfc3339(~Z[2019-12-14 08:06:24.289659]) &quot;2019-12-14 08:06:24.289659&quot;"},{"ref":"UTCDateTime.html#utc_now/0","title":"UTCDateTime.utc_now/0","type":"function","doc":"Returns the current UTC datetime. Examples iex&gt; utc_datetime = UTCDateTime.utc_now() iex&gt; utc_datetime.year &gt;= 2016 true"},{"ref":"UTCDateTime.html#t:t/0","title":"UTCDateTime.t/0","type":"type","doc":"A datetime implementation constraint to UTC."},{"ref":"readme.html","title":"UTC DateTime","type":"extras","doc":"UTC DateTime A datetime implementation constraint to UTC."},{"ref":"readme.html#goal","title":"UTC DateTime - Goal","type":"extras","doc":"The goal is to create datetime type, which unlike DateTime guarantees to be UTC only, without ignoring the existence of timezones like a NaiveDateTime. A secondary goal is to be more efficient or at least on par with the build in datetimes. (DateTime, NaiveDateTime) In practice the goal is to use less memory and perform common [shared] actions faster."},{"ref":"readme.html#quick-setup","title":"UTC DateTime - Quick Setup","type":"extras","doc":"iex&gt; UTCDateTime.utc_now ~Z[2019-12-14 16:08:13.042407]"},{"ref":"readme.html#installation","title":"UTC DateTime - Installation","type":"extras","doc":"The package can be installed by adding utc_datetime to your list of dependencies in mix.exs: def deps do [ {:utc_datetime, &quot;~&gt; 0.0.1&quot;} ] end The docs can be found at https://hexdocs.pm/utc_datetime."},{"ref":"readme.html#integration","title":"UTC DateTime - Integration","type":"extras","doc":"Currently UTCDateTime does not integrate with other libraries. Please check back later, because integrations are on the roadmap."},{"ref":"readme.html#changelog","title":"UTC DateTime - Changelog","type":"extras","doc":"v0.0.1 (2019-12-14) Base UTCDateTime. New Features: from_datetime/1 from_naive/1 to_datetime/1, to_datetime/2 to_naive/1, to_naive/2 utc_now/0 Experimental: ~Z sigil for UTCDateTime RFC3339 support Additional: Benchmarks Roadmap"},{"ref":"readme.html#roadmap","title":"UTC DateTime - Roadmap","type":"extras","doc":"Integrations :fixtures :time_machinex Release 0.0.1 Conversions (datetime / naive) Benchmarks Changelog Readme List Integrations Roadmap Release 0.0.2 Conversion rfc3339 Sigil Conversion iso8601 to_string String parsing Benchmarks Release 0.0.3 Epochs Release 0.0.4 Conversions erl/etc to_date/1 to_time/1 from_date_and_time/2 (optional time) Benchmarks Release 0.0.5 Benchmarks page Ecto Support Benchmarks Release 0.0.6 Jason support Benchmarks Release 0.0.7 Add / Diff / Truncate Benchmarks Release 0.0.8 To Unix To windows to_epoch(epoch, time_unit) Benchmarks Release 0.0.9 to_local_datetime/1 (in caller) Release 0.0.10 from_human/1 best effort parse"},{"ref":"readme.html#copyright-and-license","title":"UTC DateTime - Copyright and License","type":"extras","doc":"Copyright (c) 2019, Ian Luites. UTCDateTime code is licensed under the MIT License."}]